@@ -159,7 +159,7 @@ class CloudArtifact(
             properties=properties,
         )
 
-        jsii.create(CloudArtifact, self, [assembly, id, manifest])
+        jsii.create(self.__class__, self, [assembly, id, manifest])
 
     @jsii.member(jsii_name="fromManifest") # type: ignore[misc]
     @builtins.classmethod
@@ -245,7 +245,7 @@ class CloudAssembly(
 
         :param directory: The root directory of the assembly.
         '''
-        jsii.create(CloudAssembly, self, [directory])
+        jsii.create(self.__class__, self, [directory])
 
     @jsii.member(jsii_name="getNestedAssembly")
     def get_nested_assembly(self, artifact_id: builtins.str) -> "CloudAssembly":
@@ -374,7 +374,7 @@ class CloudAssemblyBuilder(
 
         :param outdir: The output directory, uses temporary directory if undefined.
         '''
-        jsii.create(CloudAssemblyBuilder, self, [outdir])
+        jsii.create(self.__class__, self, [outdir])
 
     @jsii.member(jsii_name="addArtifact")
     def add_artifact(
@@ -719,7 +719,7 @@ class NestedCloudAssemblyArtifact(
             properties=properties,
         )
 
-        jsii.create(NestedCloudAssemblyArtifact, self, [assembly, name, artifact])
+        jsii.create(self.__class__, self, [assembly, name, artifact])
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="directoryName")
@@ -776,7 +776,7 @@ class RosStackArtifact(
             properties=properties,
         )
 
-        jsii.create(RosStackArtifact, self, [assembly, artifact_id, artifact])
+        jsii.create(self.__class__, self, [assembly, artifact_id, artifact])
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="displayName")
@@ -818,6 +818,11 @@ class RosStackArtifact(
         '''The physical name of this stack.'''
         return typing.cast(builtins.str, jsii.get(self, "stackName"))
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="tags")
+    def tags(self) -> typing.Any:
+        return typing.cast(typing.Any, jsii.get(self, "tags"))
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="template")
     def template(self) -> typing.Any:
@@ -970,7 +975,7 @@ class TreeCloudArtifact(
             properties=properties,
         )
 
-        jsii.create(TreeCloudArtifact, self, [assembly, name, artifact])
+        jsii.create(self.__class__, self, [assembly, name, artifact])
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="file")
